"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import contentdetectorrequest as shared_contentdetectorrequest
from ..shared import contentdetectorresponse as shared_contentdetectorresponse
from typing import Dict, List, Optional


@dataclasses.dataclass
class DetectContentRequest:
    content_detector_request: shared_contentdetectorrequest.ContentDetectorRequest = dataclasses.field(metadata={'request': { 'media_type': 'application/json' }})
    organization_id: Optional[int] = dataclasses.field(default=None, metadata={'path_param': { 'field_name': 'organizationId', 'style': 'simple', 'explode': False }})
    



@dataclasses.dataclass
class DetectContentResponse:
    content_type: str = dataclasses.field()
    r"""HTTP response content type for this operation"""
    status_code: int = dataclasses.field()
    r"""HTTP response status code for this operation"""
    content_detector_responses: Optional[List[shared_contentdetectorresponse.ContentDetectorResponse]] = dataclasses.field(default=None)
    headers: Optional[Dict[str, List[str]]] = dataclasses.field(default=None)
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    r"""Raw HTTP response; suitable for custom response parsing"""
    

